#! /usr/bin/env python
# -*- coding: utf-8 -*-
###########################################################################
#
# Eole NG
# Copyright Pole de Competence Eole (Ministere Education - Academie Dijon)
# Licence CeCill  http://www.cecill.info/licences/Licence_CeCILL_V2-fr.html
# eole@ac-dijon.fr
#
###########################################################################
import sys
from os import system
from time import sleep
from os.path import isfile
from subprocess import Popen, PIPE
from creole import parsedico
from creole.eosfunc import gen_random
from creole.utils import print_red, print_green, print_orange
from scribe.eoleldap import Ldap
from scribe.eoletools import format_current_date, sshaDigest
from zephir import lib_zephir

def err_msg(message):
    """
    Sortie avec message d'erreur
    """
    print_red("Erreur : ", newline=False)
    print message
    print
    sys.exit(1)

def readdefault(message, valeur):
    """
    Question avec valeur proposée
    """
    print message
    res = raw_input('[%s] : ' % valeur)
    if not res:
        return valeur
    else:
        return res

def send_zephir(conf_data):
    """
    Envoi de la configuration à Zephir pour prise en compte par le serveur de réplication
    """
    from zephir.zephir_conf.zephir_conf import id_serveur, adresse_zephir
    print_green("\nEnvoi de la configuration sur Zephir")
    import sys, xmlrpclib, getpass, base64
    try:
        login = ""
        con_ok = False
        zephir_proxy = None
        while not con_ok:
            # saisie des informations de connexion
            login = raw_input("\nVeuillez saisir votre identifiant Zéphir (rien pour annuler l'envoi) :")
            if login == "":
                return False
            passwd = getpass.getpass('Mot de passe pour %s :' % login)
            zephir_proxy = xmlrpclib.ServerProxy("https://%s:%s@%s:7080" % (login,passwd,adresse_zephir), transport=lib_zephir.TransportEole())
            # test des identifiants
            try:
                res = lib_zephir.convert(zephir_proxy.get_permissions(login))
                assert res[0] == 1
                con_ok = True
            except:
                print_red('Erreur de connexion au serveur ou indentifiants incorrects')
        # saisie du serveur de réplication
        num_serv = ""
        serv_ok = False
        while not serv_ok:
            num_serv = raw_input("\nIdentifiant Zéphir du serveur de réplication (rien pour annuler l'envoi) :")
            if num_serv == "":
                return False
            # vérification des données
            try:
                res = lib_zephir.convert(zephir_proxy.uucp.add_replication(int(num_serv), id_serveur, base64.encodestring(conf_data)))
                # Envoi des données de configuration
                if res[0] != 1:
                    print_red("Erreur lors de l'envoi à zephir : %s" % str(res[1]))
                else:
                    serv_ok = True
                print_green("""Cette configuration sera prise en compte par le serveur
de réplication lors de sa prochaine connexion à Zéphir""")

            except xmlrpclib.ProtocolError:
                print_red('Serveur %s non retrouvé ou permissions insuffisantes' % num_serv)
            except Exception, e:
                print_red("Erreur lors de l'envoi de la configuration à Zéphir : %s" % str(e))
    except:
        # erreur de récupération
        sys.exit("Erreur d'envoi de la configuration sur zephir")

dico = parsedico.parse_dico()
ldif = "/root/annuaire-%s.ldif" % format_current_date()
conf = "/root/replication-%(numero_etab)s.conf" % dico
replicator = "/root/.replicator"
print
# test de la vestion d'openldap
cmd = "dpkg-query -W -f='${Version}' 'slapd'"
slapd = Popen(cmd, shell=True, stdout=PIPE).stdout.read()
if 'eole' not in slapd:
    err_msg("Mise à jour du paquet slapd nécessaire")

# test du dictionnaire
if dico.get('ldap_replication', '') != 'oui':
    err_msg("""Vous devez d'abord activer la réplication ldap
dans l'interface de configuration du module (mode expert)
et reconfigurer votre serveur""")

# test de la configuration réelle
if file('/etc/ldap/slapd.conf').read().find('syncprov') == -1:
    err_msg("""Votre serveur est mal paramétré, lancez la commande reconfigure""")

print_green("Sauvegarde de l'annuaire dans %s" % ldif)
print
# test double activation
if isfile(ldif):
    err_msg("""Le fichier %s existe déjà !""" % ldif)

system("/etc/init.d/slapd stop")
system("slapcat | grep -Ev '^(entryUUID|entryCSN|structuralObjectClass)' > %s" % ldif)
print
print_green("Réindexation de l'annuaire")
system("rm -f /var/lib/ldap/*.*")
system("slapadd -l %s" % ldif)
system("chown openldap:openldap /var/lib/ldap/*.*")
print
system("/etc/init.d/slapd start")
print
# présence du réplicator
if file(ldif).read().find('cn=replicator,o=gouv,c=fr') != -1:
    print_orange("Le compte de réplication existe déjà")
    print
    if not isfile(replicator):
        replicator_pwd = ''
    else:
        replicator_pwd = file(replicator).read().strip()
    if replicator_pwd != '':
        print_green("Utilisation du compte de réplication existant")
        print
    else:
        err_msg("impossible de récupérer le mot de passe du compte de réplication")
else:
    print_green("Création du compte de réplication")
    print
    sleep(2)
    replicator_pwd = gen_random()
    rdn = "cn=replicator,o=gouv,c=fr"
    datas = [('objectClass', 'person'),
             ('cn', 'replicator'),
             ('sn', 'Compte de replication'),
             ('userPassword', sshaDigest(replicator_pwd))]
    conn = Ldap()
    conn.connect()
    conn._add(rdn, datas)
    conn.close()
    fic = file(replicator, 'w')
    fic.write(replicator_pwd)
    fic.close()
print_green("Génération de la configuration client")
adresse_scribe = readdefault("Adresse utilisée pour accéder au Scribe depuis le client", dico['adresse_ip_eth0'])
libelle = dico['libelle_etab'].replace('%', '%%')
numero = dico['numero_etab'].replace('%', '%%')
acad = dico['nom_academie'].replace('%', '%%')
print
print_green("Ecriture du fichier %s" % conf)
tmpl = """# %s (%s)
syncrepl rid=%%i
        provider=ldap://%s:389
        type=refreshAndPersist
        interval=00:01:00:00
        searchbase="ou=%s,ou=%s,ou=education,o=gouv,c=fr"
        filter="(&(objectClass=ENTPerson)(!(uid=admin)))"
        scope=sub
        schemachecking=off
        bindmethod=simple
        binddn="cn=replicator,o=gouv,c=fr"
        credentials=%s

""" % (libelle, numero, adresse_scribe, numero, acad, replicator_pwd)
fic = file(conf, 'w')
fic.write(tmpl)
fic.close()
# La configuration est générée localement, on l'envoie via zephir si possible
if lib_zephir.registered == 1:
    send_zephir(tmpl)
print
print "fin"
