#-*-coding:utf-8-*-
###########################################################################
# Eole NG - 2009
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# sympa.py
#
# Configuration de base de données mysql de sympa
#
###########################################################################
"""
    Config pour sympa
"""
from os import system
from os.path import isfile, isdir, join
from eolesql.config import dico_creole
SYMPA_TABLEFILENAMES = ["/usr/share/doc/sympa/examples/db/create_db.mysql"]
REMOVE_BDD_QUERY = "DROP DATABASE IF EXISTS %s"

domaine_mail = dico_creole.get('domaine_messagerie_etab')
ETC_DIRNAME = join("/etc/sympa/", "i-%s" % (domaine_mail,))
VARLIB_DIRNAME = join("/var/lib/sympa/expl/", "i-%s" % (domaine_mail,))

def test():
    """
        test l'existence de la table Posh
    """
    return not isfile("/var/lib/mysql/sympa/user_table.frm")

def pregen_func(db_handler):
    """
        Fonction éxécutée avant la génération si le test est bon
    """
    db_handler.delete(REMOVE_BDD_QUERY % ("sympa",))

def add_etc_dir():
    """
        Ajoute le rep /etc/sympa/i-$domaine_messagerie_etab
    """
    if not isdir(ETC_DIRNAME):
        system("mkdir -p %s" % (ETC_DIRNAME,))
        system("chown sympa:sympa %s" % (ETC_DIRNAME,))

def add_varlib_dir():
    """
        Ajoute le rep /var/lib/sympa/expl/i-$domaine_messagerie_etab
    """
    system("mkdir -p %s" % (VARLIB_DIRNAME,))
    system("chown sympa:sympa %s" % (VARLIB_DIRNAME,))

def add_aliases():
    """
        Ajoute les alias pour sympa
    """
    system('echo "sympa: \"|/usr/lib/sympa/bin/queue sympa\"" >> /etc/mail/sympa_aliases')
    system('chown sympa:sympa /etc/mail/sympa_aliases')
    system('chmod 644 /etc/mail/sympa_aliases')

def postgen_func(db_handler):
    """
        Fonction éxécutée après la génération si le test est bon
    """
    db_handler.simple_query("grant select,insert,update,delete,alter ON sympa.* TO sympa@localhost IDENTIFIED BY 'sympa';")
    add_etc_dir()
    if not isdir(VARLIB_DIRNAME):
        add_varlib_dir()
        add_aliases()
        from scribe.eolegroup import Group
        group = Group()
        group.add_maillist('Groupe', 'professeurs', 'restreint')
        group.add_maillist('Groupe', 'eleves', 'restreint')
        group.add_maillist('Groupe', 'administratifs', 'restreint')

conf_dict = dict(filenames=SYMPA_TABLEFILENAMES,
                 test=test,
                 pregen=pregen_func,
                 postgen=postgen_func,
                 )
