#!/bin/bash

############################
# reconf-scribe.sh
# instructions spécifiques
# pour la reconfiguration
# du module Scribe
############################

# Appel Bibliothèque
. ParseDico

/etc/init.d/nscd stop &>/dev/null

# FIXES BUG #1621
cp -f /etc/sysconfig/eole/global_smb.tmpl /etc/samba/smb.conf

echo -e "\n## gestion du mot de passe LDAP ##"
/usr/share/eole/backend/ldap_pwd.py `/usr/bin/pwgen -1`> /dev/null

# pour les serveurs lents
sleep 1

echo -e "\n## gestion du SID ##"
net setlocalsid `ldapsearch -x sambaDomainName=* | grep sambaSID | awk -F " " '{print $2}'`
/usr/share/eole/set_sid.sh

# ajout de la branche autres
ldapsearch -x ou=autres ou | grep -q "^ou: autres"
r1=$?
ldapsearch -x sambaShareDrive=* sambaShareDrive | grep -q ^sambaShareDrive
r2=$?
if [ $r1 -ne 0 -o $r2 -ne 0 ]
then
	echo -e "\nMise à niveau de l'annuaire..."
	ldif=/root/annuaire-`date +%F`.ldif
	if [ -f $ldif ];then
		echo -e "\n** Le fichier de sauvegarde $ldif existe déjà ! **\n"
	else
		echo -e "\n** Sauvegarde de l'annuaire dans $ldif **\n"
		/usr/sbin/slapcat > $ldif
	fi
	/usr/share/eole/backend/upgrade_scribe.py
fi
# ajout/vérification de l'utilisateur reader
/usr/share/eole/backend/gen_reader.py >/dev/null

echo -e "\n## génération de la configuration Samba ##"
/usr/share/eole/backend/synchro_file.py norestart

echo
# Génération des bases de données
/usr/share/eole/gen_databases.py
echo
# Mise à jour des bases de données
/usr/share/eole/update_databases.py
echo

## re-création de l'utilisateur admin
id admin &>/dev/null
if [ $? -ne 0 ]
then
	/usr/share/eole/backend/creation-prof.py -u admin -m admin -p admin -f admin -M 'local' -z 1 -G DomainAdmins,PrintOperators -q 0 -x 1
	# le mot de passe doit être changé à la prochaine connexion
	/usr/bin/net sam set pwdmustchangenow admin yes &>/dev/null
        tput setaf 3; echo -n "L'utilisateur "
        tput smso; echo -n admin; tput rmso
        tput setaf 3; echo -n " a été re-créé avec le mot de passe "
        tput setaf 8; echo "admin"
        tput setaf 3; echo "Le système demandera son changement à la prochaine ouverture de session"
        tput sgr0
	echo
fi

# FIXME On relance le script de firewall
#/usr/sbin/lance.firewall

# copie du fichier de conf du domaine interne SYMPA
if [ ! -d /etc/sympa/i-$domaine_messagerie_etab ]
then
	echo "ATTENTION ! Le domaine de messagerie semble avoir changé"
	echo "Des dysfonctionnements sont possibles..."
	echo
	mkdir -p /etc/sympa/i-$domaine_messagerie_etab
	chown sympa.sympa /etc/sympa/i-$domaine_messagerie_etab
fi
mv /tmp/robot.conf /etc/sympa/i-$domaine_messagerie_etab/

# si Cups est desactivé
touch /etc/printcap

/etc/init.d/nscd start &>/dev/null

# Bacula
[ ! -e /etc/bacula/eoleschedule.conf ] && touch /etc/bacula/eoleschedule.conf
[ ! -e /etc/bacula/eoleschedulerestreint.conf ] && touch /etc/bacula/eoleschedulerestreint.conf
[ ! -e /etc/bacula/eolemessages.conf ] && touch /etc/bacula/eolemessages.conf
[ ! -e /etc/bacula/typesupport.conf ] && /usr/share/eole/bacula/baculasupport.py -s distant 1>/dev/null
[ ! -e /etc/bacula/listefichiersperso.conf ] && touch /etc/bacula/listefichiersperso.conf
[ ! -e /etc/bacula/listefichiersexperso.conf ] && touch /etc/bacula/listefichiersexperso.conf
[ ! -e /etc/bacula/listefichiersacad.conf ] && touch /etc/bacula/listefichiersacad.conf
[ ! -e /etc/bacula/listefichiersexacad.conf ] && touch /etc/bacula/listefichiersexacad.conf

exit 0
